from setuptools import setup

setup(name='gaussian_binomial_probability_new',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['distributions'],
      author = 'Adarsh Vinayak',
      zip_safe=False)
